# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`smartd`](#smartd): Manage the smartmontools package including the smartd daemon
* [`smartd::params`](#smartd--params): == Class: smartd::params  This class should be considered private.  === Authors  MIT Computer Science & Artificial Intelligence Laboratory Jo

### Data types

* [`Smartd::Ensure`](#Smartd--Ensure): Valid values for ensure parameter
* [`Smartd::Warning_schedule`](#Smartd--Warning_schedule): Type of warning schedule, used for -M option of devicescan

## Classes

### <a name="smartd"></a>`smartd`

smartd/manifests/init.pp

- Copyright (C) 2012 MIT Computer Science & Artificial Intelligence Laboratory
- Copyright (C) 2013-2015 Joshua Hoblitt <jhoblitt@cpan.org>
- Copyright (C) 2015-2023 Gabriel Filion <gabster@lelutin.ca>

#### Examples

##### basic usage

```puppet
class { 'smartd': }
```

#### Parameters

The following parameters are available in the `smartd` class:

* [`ensure`](#-smartd--ensure)
* [`package_name`](#-smartd--package_name)
* [`service_name`](#-smartd--service_name)
* [`service_ensure`](#-smartd--service_ensure)
* [`manage_service`](#-smartd--manage_service)
* [`config_file`](#-smartd--config_file)
* [`devicescan`](#-smartd--devicescan)
* [`devicescan_options`](#-smartd--devicescan_options)
* [`devices`](#-smartd--devices)
* [`mail_to`](#-smartd--mail_to)
* [`warning_schedule`](#-smartd--warning_schedule)
* [`exec_script`](#-smartd--exec_script)
* [`enable_default`](#-smartd--enable_default)
* [`default_options`](#-smartd--default_options)

##### <a name="-smartd--ensure"></a>`ensure`

Data type: `Smartd::Ensure`

Standard Puppet ensure semantics (supports `purged` state if your
package provider does). Defaults to `present`. Valid values are:
`present`,`latest`,`absent`,`purged`

Default value: `'present'`

##### <a name="-smartd--package_name"></a>`package_name`

Data type: `String[1]`

Name of the smartmontools package.

Default value: `$smartd::params::package_name`

##### <a name="-smartd--service_name"></a>`service_name`

Data type: `String[1]`

Name of the smartmontools monitoring daemon.

Default value: `$smartd::params::service_name`

##### <a name="-smartd--service_ensure"></a>`service_ensure`

Data type: `Enum['running', 'stopped']`

State of the smartmontools monitoring daemon. Defaults to `running`. Valid
values are:
`running`,`stopped`

Default value: `$smartd::params::service_ensure`

##### <a name="-smartd--manage_service"></a>`manage_service`

Data type: `Boolean`

Set this to false to disable managing the smartmontools service.
This parameter is disregarded when $ensure = absent|purge.

Default value: `$smartd::params::manage_service`

##### <a name="-smartd--config_file"></a>`config_file`

Data type: `Stdlib::Absolutepath`

Path to the configuration file for the monitoring daemon.

Default value: `$smartd::params::config_file`

##### <a name="-smartd--devicescan"></a>`devicescan`

Data type: `Boolean`

Sets the `DEVICESCAN` directive in the smart daemon config file.  Tells the
smart daemon to automatically detect all of the SMART-capable drives in the
system. Defaults to`true`.

Default value: `$smartd::params::devicescan`

##### <a name="-smartd--devicescan_options"></a>`devicescan_options`

Data type: `String`

String of options to the `DEVICESCAN` directive. `devicescan` must equal true
for this to have any effect.

Default value: `$smartd::params::devicescan_options`

##### <a name="-smartd--devices"></a>`devices`

Data type: `Array[Hash]`

`Array` of `Hash`. Explicit list of raw block devices to check.  Eg.
 [{ device => '/dev/sda', options => '-I 194' }]

Default value: `$smartd::params::devices`

##### <a name="-smartd--mail_to"></a>`mail_to`

Data type: `String`

Local username or email address used by smart daemon for notifcations.
Defaults to `root`

Default value: `$smartd::params::mail_to`

##### <a name="-smartd--warning_schedule"></a>`warning_schedule`

Data type: `Smartd::Warning_schedule`

Smart daemon problem mail notification frequency. Defaults to `daily`.
Valid values are: `daily`,`once`,`diminishing`, `exec`
Note that if the value `exec` is used, then the parameter `exec_script`
*must* be specified.

Default value: `$smartd::params::warning_schedule`

##### <a name="-smartd--exec_script"></a>`exec_script`

Data type: `Optional[String]`

Path to the script that should be executed if `warning_schedule` is set to
`exec`.

Default value: `$smartd::params::exec_script`

##### <a name="-smartd--enable_default"></a>`enable_default`

Data type: `Boolean`

Set this to false to disable the `DEFAULT` directive in the `smartd.conf`
file. The `DEFAULT` directive was added in the 5.43 release of
smartmontools.
If this parameter is set to false, then the values from the `mail_to` and
`warning_schedule` parameters are set o nthe `DEVICESCAN` directive (if
enabled) instead of the (absent) `DEFAULT` directive.

Default value: `$smartd::params::enable_default`

##### <a name="-smartd--default_options"></a>`default_options`

Data type: `String`

String of additional arguments to be set on the `DEFAULT` directive.
If `enable_default` is set to false, the value for this parameter will be
set on the `DEVICESCAN` directive (if enabled) instead of the (absent)
`DEFAULT` directive.

Default value: `$smartd::params::default_options`

### <a name="smartd--params"></a>`smartd::params`

== Class: smartd::params

This class should be considered private.

=== Authors

MIT Computer Science & Artificial Intelligence Laboratory
Joshua Hoblitt <jhoblitt@cpan.org>

=== Copyright

Copyright 2012 Massachusetts Institute of Technology
Copyright (C) 2013 Joshua Hoblitt

## Data types

### <a name="Smartd--Ensure"></a>`Smartd::Ensure`

Valid values for ensure parameter

Alias of `Enum['present', 'latest', 'absent', 'purged']`

### <a name="Smartd--Warning_schedule"></a>`Smartd::Warning_schedule`

Type of warning schedule, used for -M option of devicescan

* **See also**
  * https://linux.die.net/man/5/smartd.conf

Alias of `Enum['daily', 'once', 'diminishing', 'exec']`

